@@ -5,13 +5,21 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.001';
+our $VERSION = '0.004';
 my $version = $VERSION;
 $VERSION = eval $VERSION;
 
 use App::TestOnTap::Args;
 use App::TestOnTap::Harness;
 
+# These are (known) implicit dependencies, and listing them like this
+# allows scanners like perlapp to pick up on them
+# 
+require TAP::Parser if 0;
+require TAP::Parser::Aggregator if 0;
+require TAP::Parser::Multiplexer if 0;
+require TAP::Formatter::Console::ParallelSession if 0;
+
 # main entry point
 #
 sub main
@@ -46,6 +54,6 @@ App::TestOnTap - Test driver
 
 =head1 VERSION
 
-Version 0.001
+Version 0.004
 
 =cut
